##  Prerequisites
  * Before you start, learn about the SSO configuration process in [SSO Configuration Process](https://help.sap.com/docs/leanix/ea/sso-configuration-process?locale=en-US&state=PRODUCTION&version=CLOUD).
  * You need administrator permission in SAP Cloud Identity Services. For additional information, visit [SAP Cloud Identity Services](https://help.sap.com/docs/cloud-identity-services?locale=en-US "https://help.sap.com/docs/cloud-identity-services?locale=en-US").
